summaryrefslogtreecommitdiff
path: root/src/vm
diff options
context:
space:
mode:
authorMukul Sabharwal <mjsabby@gmail.com>2019-05-22 01:52:38 -0700
committerDavid Mason <davmason@microsoft.com>2019-05-22 01:52:37 -0700
commit797be5d5c87a81f50dbd59e000abd2db7b99237a (patch)
tree1174d14c70ea421f2a559ad03b05e6c26d0d8c49 /src/vm
parentf33ffab85335b9ca6b0f669d59de599e981c295f (diff)
downloadcoreclr-797be5d5c87a81f50dbd59e000abd2db7b99237a.tar.gz
coreclr-797be5d5c87a81f50dbd59e000abd2db7b99237a.tar.bz2
coreclr-797be5d5c87a81f50dbd59e000abd2db7b99237a.zip
Track debug info for DynamicMethods for Profiler API (#24139)
Diffstat (limited to 'src/vm')
-rw-r--r--src/vm/eeconfig.cpp2
-rw-r--r--src/vm/eeconfig.h26
-rw-r--r--src/vm/jitinterface.cpp4
3 files changed, 17 insertions, 15 deletions
diff --git a/src/vm/eeconfig.cpp b/src/vm/eeconfig.cpp
index 87e7467f23..83c1f1e904 100644
--- a/src/vm/eeconfig.cpp
+++ b/src/vm/eeconfig.cpp
@@ -704,6 +704,8 @@ HRESULT EEConfig::sync()
// Note the global variable is not updated directly by the GetRegKey function
// so we only update it once (to avoid reentrancy windows)
+fTrackDynamicMethodDebugInfo = CLRConfig::GetConfigValue(CLRConfig::UNSUPPORTED_TrackDynamicMethodDebugInfo);
+
#ifdef _DEBUG
iFastGCStress = GetConfigDWORD_DontUse_(CLRConfig::INTERNAL_FastGCStress, iFastGCStress);
diff --git a/src/vm/jitinterface.cpp b/src/vm/jitinterface.cpp
index ef3b9d0e70..cf177a3b4d 100644
--- a/src/vm/jitinterface.cpp
+++ b/src/vm/jitinterface.cpp
@@ -11179,7 +11179,7 @@ void CEEJitInfo::CompressDebugInfo()
} CONTRACTL_END;
// Don't track JIT info for DynamicMethods.
- if (m_pMethodBeingCompiled->IsDynamicMethod())
+ if (m_pMethodBeingCompiled->IsDynamicMethod() && !g_pConfig->GetTrackDynamicMethodDebugInfo())
return;
if (m_iOffsetMapping == 0 && m_iNativeVarInfo == 0)
@@ -12713,7 +12713,7 @@ CORJIT_FLAGS GetCompileFlags(MethodDesc * ftn, CORJIT_FLAGS flags, CORINFO_METHO
flags.Set(CORJIT_FLAGS::CORJIT_FLAG_SKIP_VERIFICATION);
- if (ftn->IsILStub())
+ if (ftn->IsILStub() && !g_pConfig->GetTrackDynamicMethodDebugInfo())
{
// no debug info available for IL stubs
flags.Clear(CORJIT_FLAGS::CORJIT_FLAG_DEBUG_INFO);
diff --git a/src/vm/eeconfig.h b/src/vm/eeconfig.h
index f96a5a214c..c95226555f 100644
--- a/src/vm/eeconfig.h
+++ b/src/vm/eeconfig.h
@@ -273,13 +273,13 @@ public:
// Jit-config
- DWORD JitHostMaxSlabCache(void) const {LIMITED_METHOD_CONTRACT; return dwJitHostMaxSlabCache; }
-
- unsigned int GenOptimizeType(void) const {LIMITED_METHOD_CONTRACT; return iJitOptimizeType; }
- bool JitFramed(void) const {LIMITED_METHOD_CONTRACT; return fJitFramed; }
- bool JitAlignLoops(void) const {LIMITED_METHOD_CONTRACT; return fJitAlignLoops; }
- bool AddRejitNops(void) const {LIMITED_METHOD_DAC_CONTRACT; return fAddRejitNops; }
- bool JitMinOpts(void) const {LIMITED_METHOD_CONTRACT; return fJitMinOpts; }
+ DWORD JitHostMaxSlabCache(void) const {LIMITED_METHOD_CONTRACT; return dwJitHostMaxSlabCache; }
+ bool GetTrackDynamicMethodDebugInfo(void) const {LIMITED_METHOD_CONTRACT; return fTrackDynamicMethodDebugInfo; }
+ unsigned int GenOptimizeType(void) const {LIMITED_METHOD_CONTRACT; return iJitOptimizeType; }
+ bool JitFramed(void) const {LIMITED_METHOD_CONTRACT; return fJitFramed; }
+ bool JitAlignLoops(void) const {LIMITED_METHOD_CONTRACT; return fJitAlignLoops; }
+ bool AddRejitNops(void) const {LIMITED_METHOD_DAC_CONTRACT; return fAddRejitNops; }
+ bool JitMinOpts(void) const {LIMITED_METHOD_CONTRACT; return fJitMinOpts; }
// Tiered Compilation config
#if defined(FEATURE_TIERED_COMPILATION)
@@ -784,12 +784,12 @@ private: //----------------------------------------------------------------
// Jit-config
- DWORD dwJitHostMaxSlabCache; // max size for jit host slab cache
-
- bool fJitFramed; // Enable/Disable EBP based frames
- bool fJitAlignLoops; // Enable/Disable loop alignment
- bool fAddRejitNops; // Enable/Disable nop padding for rejit. default is true
- bool fJitMinOpts; // Enable MinOpts for all jitted methods
+ DWORD dwJitHostMaxSlabCache; // max size for jit host slab cache
+ bool fTrackDynamicMethodDebugInfo; // Enable/Disable tracking dynamic method debug info
+ bool fJitFramed; // Enable/Disable EBP based frames
+ bool fJitAlignLoops; // Enable/Disable loop alignment
+ bool fAddRejitNops; // Enable/Disable nop padding for rejit. default is true
+ bool fJitMinOpts; // Enable MinOpts for all jitted methods
unsigned iJitOptimizeType; // 0=Blended,1=SmallCode,2=FastCode, default is 0=Blended